@@ -43,7 +43,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Top Hat';
-our $VERSION  = '4.53';
+our $VERSION  = '4.54';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -232,6 +232,131 @@ Mojolicious - Real-time web framework
 
 Take a look at our excellent documentation in L<Mojolicious::Guides>!
 
+=head1 HOOKS
+
+L<Mojolicious> will emit the following hooks in the listed order.
+
+=head2 after_build_tx
+
+Emitted right after the transaction is built and before the HTTP request gets
+parsed.
+
+  $app->hook(after_build_tx => sub {
+    my ($tx, $app) = @_;
+    ...
+  });
+
+This is a very powerful hook and should not be used lightly, it makes some
+rather advanced features such as upload progress bars possible. Note that this
+hook will not work for embedded applications. (Passed the transaction and
+application object)
+
+=head2 before_dispatch
+
+Emitted right before the static file server and router start their work.
+
+  $app->hook(before_dispatch => sub {
+    my $c = shift;
+    ...
+  });
+
+Very useful for rewriting incoming requests and other preprocessing tasks.
+(Passed the default controller object)
+
+=head2 after_static
+
+Emitted after a static file response has been generated by the static file
+server.
+
+  $app->hook(after_static => sub {
+    my $c = shift;
+    ...
+  });
+
+Mostly used for post-processing static file responses. (Passed the default
+controller object)
+
+=head2 before_routes
+
+Emitted after the static file server determined if a static file should be
+served and before the router starts its work.
+
+  $app->hook(before_routes => sub {
+    my $c = shift;
+    ...
+  });
+
+Mostly used for custom dispatchers and collecting metrics. (Passed the default
+controller object)
+
+=head2 around_action
+
+Emitted right before an action gets invoked and wraps around it, so you have
+to manually forward to the next hook if you want to continue the chain.
+Default action dispatching is the last hook in the chain, yours will run
+before it.
+
+  $app->hook(around_action => sub {
+    my ($next, $c, $action, $last) = @_;
+    ...
+    return $next->();
+  });
+
+This is a very powerful hook and should not be used lightly, it allows you for
+example to pass additional arguments to actions or handle return values
+differently. (Passed a callback leading to the next hook, the current
+controller object, the action callback and a flag indicating if this action is
+an endpoint)
+
+=head2 after_render
+
+Emitted after content has been generated by the renderer that is not partial.
+Note that this hook can trigger out of order due to its dynamic nature, and
+with embedded applications will only work for the application that is
+rendering.
+
+  $app->hook(after_render => sub {
+    my ($c, $output, $format) = @_;
+    ...
+  });
+
+Mostly used for post-processing dynamically generated content. (Passed the
+current controller object, a reference to the content and the format)
+
+=head2 after_dispatch
+
+Emitted in reverse order after a response has been rendered. Note that this
+hook can trigger out of order due to its dynamic nature, and with embedded
+applications will only work for the application that is rendering.
+
+  $app->hook(after_dispatch => sub {
+    my $c = shift;
+    ...
+  });
+
+Useful for rewriting outgoing responses and other post-processing tasks.
+(Passed the current controller object)
+
+=head2 around_dispatch
+
+Emitted right before the L</"before_dispatch"> hook and wraps around the whole
+dispatch process, so you have to manually forward to the next hook if you want
+to continue the chain. Default exception handling with
+L<Mojolicious::Controller/"render_exception"> is the first hook in the chain
+and a call to L</"dispatch"> the last, yours will be in between.
+
+  $app->hook(around_dispatch => sub {
+    my ($next, $c) = @_;
+    ...
+    $next->();
+    ...
+  });
+
+This is a very powerful hook and should not be used lightly, it allows you for
+example to customize application wide exception handling, consider it the
+sledgehammer in your toolbox. (Passed a callback leading to the next hook and
+the default controller object)
+
 =head1 ATTRIBUTES
 
 L<Mojolicious> inherits all attributes from L<Mojo> and implements the
@@ -263,8 +388,8 @@ L<Mojolicious::Controller>.
 
 The operating mode for your application, defaults to a value from the
 MOJO_MODE and PLACK_ENV environment variables or C<development>. Right before
-calling C<startup>, L<Mojolicious> will pick up the current mode, name the log
-file after it and raise the log level from C<debug> to C<info> if it has a
+calling L</"startup">, L<Mojolicious> will pick up the current mode, name the
+log file after it and raise the log level from C<debug> to C<info> if it has a
 value other than C<development>.
 
 =head2 moniker
@@ -282,7 +407,7 @@ L<Mojo::Util/"decamelize">.
   $app        = $app->plugins(Mojolicious::Plugins->new);
 
 The plugin manager, defaults to a L<Mojolicious::Plugins> object. See the
-C<plugin> method below if you want to load a plugin.
+L</"plugin"> method below if you want to load a plugin.
 
   # Add another namespace to load plugins from
   push @{$app->plugins->namespaces}, 'MyApp::Plugin';
@@ -325,8 +450,8 @@ startup method to define the url endpoints for your application.
   $app       = $app->secret('passw0rd');
 
 A secret passphrase used for signed cookies and the like, defaults to the
-C<moniker> of this application, which is not very secure, so you should change
-it!!! As long as you are using the insecure default there will be debug
+L</"moniker"> of this application, which is not very secure, so you should
+change it!!! As long as you are using the insecure default there will be debug
 messages in the log file reminding you to change your passphrase.
 
 =head2 sessions
@@ -384,10 +509,10 @@ new ones.
   my $app = Mojolicious->new;
 
 Construct a new L<Mojolicious> application, calling C<${mode}_mode> and
-C<startup> in the process. Will automatically detect your home directory and
-set up logging based on your current operating mode. Also sets up the
+L</"startup"> in the process. Will automatically detect your home directory
+and set up logging based on your current operating mode. Also sets up the
 renderer, static file server, a default set of plugins and an
-C<around_dispatch> hook with the default exception handling.
+L</"around_dispatch"> hook with the default exception handling.
 
 =head2 build_tx
 
@@ -413,8 +538,8 @@ request.
 
   $app->dispatch(Mojolicious::Controller->new);
 
-The heart of every L<Mojolicious> application, calls the C<static> and
-C<routes> dispatchers for every request and passes them a
+The heart of every L<Mojolicious> application, calls the L</"static"> and
+L</"routes"> dispatchers for every request and passes them a
 L<Mojolicious::Controller> object.
 
 =head2 handler
@@ -447,7 +572,7 @@ and the application object, as well as a function in C<ep> templates.
   $app->hook(after_dispatch => sub {...});
 
 Extend L<Mojolicious> with hooks, which allow code to be shared with all
-requests indiscriminately.
+requests indiscriminately, for a full list of available hooks see L</"HOOKS">.
 
   # Dispatchers will not run if there's already a response code defined
   $app->hook(before_dispatch => sub {
@@ -456,133 +581,6 @@ requests indiscriminately.
       if $c->req->url->path->to_route =~ /do_not_dispatch/;
   });
 
-These hooks are currently available and are emitted in the listed order:
-
-=over 2
-
-=item after_build_tx
-
-Emitted right after the transaction is built and before the HTTP request gets
-parsed.
-
-  $app->hook(after_build_tx => sub {
-    my ($tx, $app) = @_;
-    ...
-  });
-
-This is a very powerful hook and should not be used lightly, it makes some
-rather advanced features such as upload progress bars possible. Note that this
-hook will not work for embedded applications. (Passed the transaction and
-application object)
-
-=item before_dispatch
-
-Emitted right before the static file server and router start their work.
-
-  $app->hook(before_dispatch => sub {
-    my $c = shift;
-    ...
-  });
-
-Very useful for rewriting incoming requests and other preprocessing tasks.
-(Passed the default controller object)
-
-=item after_static
-
-Emitted after a static file response has been generated by the static file
-server.
-
-  $app->hook(after_static => sub {
-    my $c = shift;
-    ...
-  });
-
-Mostly used for post-processing static file responses. (Passed the default
-controller object)
-
-=item before_routes
-
-Emitted after the static file server determined if a static file should be
-served and before the router starts its work.
-
-  $app->hook(before_routes => sub {
-    my $c = shift;
-    ...
-  });
-
-Mostly used for custom dispatchers and collecting metrics. (Passed the default
-controller object)
-
-=item around_action
-
-Emitted right before an action gets invoked and wraps around it, so you have
-to manually forward to the next hook if you want to continue the chain.
-Default action dispatching is the last hook in the chain, yours will run
-before it.
-
-  $app->hook(around_action => sub {
-    my ($next, $c, $action, $last) = @_;
-    ...
-    return $next->();
-  });
-
-This is a very powerful hook and should not be used lightly, it allows you for
-example to pass additional arguments to actions or handle return values
-differently. (Passed a callback leading to the next hook, the current
-controller object, the action callback and a flag indicating if this action is
-an endpoint)
-
-=item after_render
-
-Emitted after content has been generated by the renderer that is not partial.
-Note that this hook can trigger out of order due to its dynamic nature, and
-with embedded applications will only work for the application that is
-rendering.
-
-  $app->hook(after_render => sub {
-    my ($c, $output, $format) = @_;
-    ...
-  });
-
-Mostly used for post-processing dynamically generated content. (Passed the
-current controller object, a reference to the content and the format)
-
-=item after_dispatch
-
-Emitted in reverse order after a response has been rendered. Note that this
-hook can trigger out of order due to its dynamic nature, and with embedded
-applications will only work for the application that is rendering.
-
-  $app->hook(after_dispatch => sub {
-    my $c = shift;
-    ...
-  });
-
-Useful for rewriting outgoing responses and other post-processing tasks.
-(Passed the current controller object)
-
-=item around_dispatch
-
-Emitted right before the C<before_dispatch> hook and wraps around the whole
-dispatch process, so you have to manually forward to the next hook if you want
-to continue the chain. Default exception handling with
-L<Mojolicious::Controller/"render_exception"> is the first hook in the chain
-and a call to C<dispatch> the last, yours will be in between.
-
-  $app->hook(around_dispatch => sub {
-    my ($next, $c) = @_;
-    ...
-    $next->();
-    ...
-  });
-
-This is a very powerful hook and should not be used lightly, it allows you for
-example to customize application wide exception handling, consider it the
-sledgehammer in your toolbox. (Passed a callback leading to the next hook and
-the default controller object)
-
-=back
-
 =head2 plugin
 
   $app->plugin('some_thing');
@@ -695,7 +693,7 @@ Sebastian Riedel, C<sri@cpan.org>
 
 Current members of the core team in alphabetical order:
 
-=over 4
+=over 2
 
 Abhijit Menon-Sen, C<ams@cpan.org>
 
